@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = 'v0.3.7'; # VERSION
+our $VERSION = 'v0.3.8'; # VERSION
 
 use Moose;
 use namespace::autoclean;
@@ -13,6 +13,7 @@ with qw(
 	Business::CyberSource::Role::RequestID
 );
 
+use MooseX::Aliases;
 use MooseX::StrictConstructor;
 use MooseX::Types::Moose qw( Str Int Bool );
 use MooseX::Types::CyberSource qw( Decision );
@@ -55,102 +56,102 @@ has request_token => (
 		. 'number. The string can contain up to 256 characters.',
 );
 
-has is_success => (
+has accepted => (
 	required => 0,
 	lazy     => 1,
 	is       => 'ro',
 	isa      => Bool,
+	alias    => [ qw( is_success is_accepted ) ],
 	default  => sub {
 		my $self = shift;
 		return $self->decision eq 'ACCEPT' ? 1 : 0;
 	},
 	documentation => 'boolean way of determining whether the transaction was '
-		. 'a success',
+		. 'accepted',
 );
 
+my $reason = {
+	100 => 'Successful transaction',
+	101 => 'The request is missing one or more required fields',
+	102 => 'One or more fields in the request contains invalid data',
+	110 => 'Only a partial amount was approved',
+	150 => 'General system failure',
+	151 => 'The request was received but there was a server timeout.',
+	152 => 'The request was received, but a service did not finish '
+		. 'running in time'
+		,
+	200 => 'The authorization request was approved by the issuing bank '
+		. 'but declined by CyberSource because it did not pass the '
+		. 'Address Verification Service (AVS) check'
+		,
+	201 => 'The issuing bank has questions about the request. You do not '
+		. 'receive an authorization code programmatically, but you might '
+		. 'receive one verbally by calling the processor'
+		,
+	202 => 'Expired card. You might also receive this if the expiration '
+		. 'date you provided does not match the date the issuing bank '
+		. 'has on file'
+		,
+	203 => 'General decline of the card. No other information provided '
+		. 'by the issuing bank'
+		,
+	204 => 'Insufficient funds in the account',
+	205 => 'Stolen or lost card',
+	207 => 'Issuing bank unavailable',
+	208 => 'Inactive card or card not authorized for card-not-present '
+		. 'transactions'
+		,
+	209 => 'American Express Card Identification Digits (CID) did not '
+		. 'match'
+		,
+	210 => 'The card has reached the credit limit',
+	211 => 'Invalid CVN',
+	221 => 'The customer matched an entry on the processor\'s negative '
+		. 'file'
+		,
+	230 => 'The authorization request was approved by the issuing bank '
+		. 'but declined by CyberSource because it did not pass the CVN '
+		. 'check'
+		,
+	231 => 'Invalid account number',
+	232 => 'The card type is not accepted by the payment processor',
+	233 => 'General decline by the processor',
+	234 => 'There is a problem with your CyberSource merchant '
+		. 'configuration'
+		,
+	235 => 'The requested amount exceeds the originally authorized '
+		. 'amount'
+		,
+	236 => 'Processor failure',
+	237 => 'The authorization has already been reversed',
+	238 => 'The authorization has already been captured',
+	239 => 'The requested transaction amount must match the previous '
+		. 'transaction amount'
+		,
+	240 => 'The card type sent is invalid or does not correlate with '
+		. 'the credit card number'
+		,
+	241 => 'The request ID is invalid',
+	242 => 'You requested a capture, but there is no corresponding, '
+		. 'unused authorization record'
+		,
+	243 => 'The transaction has already been settled or reversed',
+	246 => 'The capture or credit is not voidable because the capture or '
+		. 'credit information has already been submitted to your '
+		. 'processor. Or, you requested a void for a type of '
+		. 'transaction that cannot be voided'
+		,
+	247 => 'You requested a credit for a capture that was previously '
+		. 'voided'
+		,
+	250 => 'The request was received, but there was a timeout at the '
+		. 'payment processor'
+		,
+};
 
 sub _build_reason_text {
 	my $self = shift;
 
-	my $reason = {
-		100 => 'Successful transaction',
-		101 => 'The request is missing one or more required fields',
-		102 => 'One or more fields in the request contains invalid data',
-		110 => 'Only a partial amount was approved',
-		150 => 'General system failure',
-		151 => 'The request was received but there was a server timeout.',
-		152 => 'The request was received, but a service did not finish '
-			. 'running in time'
-			,
-		200 => 'The authorization request was approved by the issuing bank '
-			. 'but declined by CyberSource because it did not pass the '
-			. 'Address Verification Service (AVS) check'
-			,
-		201 => 'The issuing bank has questions about the request. You do not '
-			. 'receive an authorization code programmatically, but you might '
-			. 'receive one verbally by calling the processor'
-			,
-		202 => 'Expired card. You might also receive this if the expiration '
-			. 'date you provided does not match the date the issuing bank '
-			. 'has on file'
-			,
-		203 => 'General decline of the card. No other information provided '
-			. 'by the issuing bank'
-			,
-		204 => 'Insufficient funds in the account',
-		205 => 'Stolen or lost card',
-		207 => 'Issuing bank unavailable',
-		208 => 'Inactive card or card not authorized for card-not-present '
-			. 'transactions'
-			,
-		209 => 'American Express Card Identification Digits (CID) did not '
-			. 'match'
-			,
-		210 => 'The card has reached the credit limit',
-		211 => 'Invalid CVN',
-		221 => 'The customer matched an entry on the processor\'s negative '
-			. 'file'
-			,
-		230 => 'The authorization request was approved by the issuing bank '
-			. 'but declined by CyberSource because it did not pass the CVN '
-			. 'check'
-			,
-		231 => 'Invalid account number',
-		232 => 'The card type is not accepted by the payment processor',
-		233 => 'General decline by the processor',
-		234 => 'There is a problem with your CyberSource merchant '
-			. 'configuration'
-			,
-		235 => 'The requested amount exceeds the originally authorized '
-			. 'amount'
-			,
-		236 => 'Processor failure',
-		237 => 'The authorization has already been reversed',
-		238 => 'The authorization has already been captured',
-		239 => 'The requested transaction amount must match the previous '
-			. 'transaction amount'
-			,
-		240 => 'The card type sent is invalid or does not correlate with '
-			. 'the credit card number'
-			,
-		241 => 'The request ID is invalid',
-		242 => 'You requested a capture, but there is no corresponding, '
-			. 'unused authorization record'
-			,
-		243 => 'The transaction has already been settled or reversed',
-		246 => 'The capture or credit is not voidable because the capture or '
-			. 'credit information has already been submitted to your '
-			. 'processor. Or, you requested a void for a type of '
-			. 'transaction that cannot be voided'
-			,
-		247 => 'You requested a credit for a capture that was previously '
-			. 'voided'
-			,
-		250 => 'The request was received, but there was a timeout at the '
-			. 'payment processor'
-			,
-	};
-
 	return $reason->{$self->reason_code};
 }
 
@@ -169,7 +170,7 @@ Business::CyberSource::Response - Response Object
 
 =head1 VERSION
 
-version v0.3.7
+version v0.3.8
 
 =head1 DESCRIPTION
 
@@ -188,14 +189,6 @@ Role|Business::CyberSource::Response::Role::Accept>
 
 =head1 ATTRIBUTES
 
-=head2 is_success
-
-Reader: is_success
-
-Type: Bool
-
-Additional documentation: boolean way of determining whether the transaction was a success
-
 =head2 reason_text
 
 Reader: reason_text
@@ -244,6 +237,14 @@ This attribute is required.
 
 Additional documentation: Request token data created by CyberSource for each reply. The field is an encoded string that contains no confidential information, such as an account or card verification number. The string can contain up to 256 characters.
 
+=head2 accepted
+
+Reader: accepted
+
+Type: Bool
+
+Additional documentation: boolean way of determining whether the transaction was accepted
+
 =head1 ATTRIBUTES
 
 =head2 amount
